package com.xinelu.manage.mapper.labelfieldinfo;

import com.xinelu.manage.domain.labelfieldinfo.LabelFieldInfo;
import com.xinelu.manage.vo.labelfieldcontent.GroupingValue;
import com.xinelu.manage.vo.labelfieldinfo.LabelFieldVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 标签字段信息Mapper接口
 *
 * @author xinelu
 * @date 2024-03-11
 */
public interface LabelFieldInfoMapper {
    /**
     * 查询标签字段信息
     *
     * @param id 标签字段信息主键
     * @return 标签字段信息
     */
    public LabelFieldInfo selectLabelFieldInfoById(Long id);

    /**
     * 查询标签字段信息列表
     *
     * @param labelFieldInfo 标签字段信息
     * @return 标签字段信息集合
     */
    public List<LabelFieldInfo> selectLabelFieldInfoList(LabelFieldInfo labelFieldInfo);

    /**
     * 查询标签字段信息列表
     *
     * @param fieldType 标签字段信息
     * @return 标签字段信息集合
     */
    List<LabelFieldVO> selectLabelFieldList(@Param("taskPartitionDictId") Long taskPartitionDictId, @Param("fieldType") String fieldType);

    /**
     * 新增标签字段信息
     *
     * @param labelFieldInfo 标签字段信息
     * @return 结果
     */
    public int insertLabelFieldInfo(LabelFieldInfo labelFieldInfo);

    /**
     * 修改标签字段信息
     *
     * @param labelFieldInfo 标签字段信息
     * @return 结果
     */
    public int updateLabelFieldInfo(LabelFieldInfo labelFieldInfo);

    /**
     * 删除标签字段信息
     *
     * @param id 标签字段信息主键
     * @return 结果
     */
    public int deleteLabelFieldInfoById(Long id);

    /**
     * 批量删除标签字段信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLabelFieldInfoByIds(Long[] ids);

    /**
     * 检查同类型下有没有重复字段名称
     */
    int countDuplicateFieldNamesByType(@Param("fieldType") String fieldType, @Param("fieldNames") List<String> fieldNames);

    /**
     * 检查除当前记录外有没有同名的字段信息名称
     */
    int countByFieldNameExcludingId(@Param("id") Long id, @Param("fieldType") String fieldType, @Param("fieldName") String fieldName);

    /**
     * 分组信息
     *
     * @return LabelFieldInfo
     */
    List<LabelFieldInfo> taskPartitionDictIdList();

    /**
     * 查询标签
     *
     * @param taskPartitionDictId 标签
     * @return GroupingValue
     */
    List<GroupingValue> selectLabelFieldInfoByTaskPartitionDictId(Long taskPartitionDictId);

    /**
     * 查询标签
     *
     * @param taskPartitionDictIds 标签
     * @return LabelFieldVO
     */
    List<LabelFieldVO> selectLabelFieldNameByTaskPartitionDictIds(@Param("taskPartitionDictIds") List<Long> taskPartitionDictIds);
}
